/******************************************************************************
 * shaderProgramShadowMap.cpp
 * implements the GLSL shader for shadow map application
 * Copyright (C) 2010 Marc Gissler <gisslerm@informatik.uni-freiburg.de>
 ******************************************************************************/

#include "shaderProgramShadowMap.h"
#include "shader_shadowmap.h"

CShaderProgramShadowMap::CShaderProgramShadowMap()
{
	// compile the shaders specified in the char strings
	if (!m_compileShader(m_vertexShader, GL_VERTEX_SHADER, shader_shadowMap_vert)
		|| !m_compileShader(m_fragmentShader, GL_FRAGMENT_SHADER, shader_shadowMap_frag)) 
	{
		printf("One of the shadowmap shaders could not be compiled.\n");
		return;
	}

	// build a shader program using the just compiled vertex and fragment shaders
	if (!m_buildShaderProgram())
	{
		printf("Shadowmap shader program could not be built.\n");
		return;
	}

	// get addresses of uniform variables in the shaders
	//TODO: see exercise sheet 4

	// set default-values of the variables
	m_shadowColor[0] = 0.2f;
	m_shadowColor[1] = 0.2f;
	m_shadowColor[2] = 1.2f;
	m_shadowColor[3] = 1.0f;
	m_shadowFactor   = 0.9f;
}

CShaderProgramShadowMap::~CShaderProgramShadowMap()
{
}

void CShaderProgramShadowMap::use()
{
	// replace fixed-functionality pipeline with the shadow map shader
	glUseProgram(m_shaderProgram);

	// communicate the values of the uniform variables to the GPU
	//TODO: see exercise sheet 4
}

void CShaderProgramShadowMap::setShadowFactor(GLfloat shadowFactor)
{ 
	// update the shadow factor
	m_shadowFactor = shadowFactor;
};

void CShaderProgramShadowMap::setShadowColor(GLfloat r, GLfloat g, GLfloat b, GLfloat a)
{ 
	// set a new shadow color
	m_shadowColor[0] = r;
	m_shadowColor[1] = g;
	m_shadowColor[2] = b;
	m_shadowColor[3] = 1.0; 
};
